This is some text.
To test the code, run the command "MdXLogseqTODOSync --input_file logseq_file.md --output_file TODO.md --required_pattern="\s+- TODO .*" --input_delim_start="Things I want to do" --input_delim_end="__END__"
<!-- BEGIN_TODO -->
qlkdjqsmdjk qsdjq
dqd
qd
qlkdjqsmdjk
<!-- END_TODO -->
Some other text
